@@ -4,20 +4,20 @@
 /*************************************************************
  *
  *  MathJax/extensions/MathEvents.js
- *  
+ *
  *  Implements the event handlers needed by the output jax to perform
  *  menu, hover, and other events.
  *
  *  ---------------------------------------------------------------------
- *  
- *  Copyright (c) 2011-2014 The MathJax Consortium
- * 
+ *
+ *  Copyright (c) 2011-2019 The MathJax Consortium
+ *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
  *  You may obtain a copy of the License at
- * 
+ *
  *      http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
  *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -26,13 +26,13 @@
  */
 
 (function (HUB,HTML,AJAX,CALLBACK,LOCALE,OUTPUT,INPUT) {
-  var VERSION = "2.4.0";
-  
+  var VERSION = "2.7.7";
+
   var EXTENSION = MathJax.Extension;
   var ME = EXTENSION.MathEvents = {version: VERSION};
-  
+
   var SETTINGS = HUB.config.menuSettings;
-  
+
   var CONFIG = {
     hover: 500,              // time required to be considered a hover
     frame: {
@@ -41,11 +41,10 @@
       bcolor: "#A6D",        // frame border color
       hwidth: "15px",        // haze width
       hcolor: "#83A"         // haze color
-    },       
+    },
     button: {
-      x: -4, y: -3,          // menu button offsets
-      wx: -2,                // button offset for full-width equations
-      src: AJAX.urlRev(OUTPUT.imageDir+"/MenuArrow-15.png")  // button image
+      x: -6, y: -3,          // menu button offsets
+      wx: -2                 // button offset for full-width equations
     },
     fadeinInc: .2,           // increment for fade-in
     fadeoutInc: .05,         // increment for fade-out
@@ -69,24 +68,61 @@
         display: "inline-block", position:"absolute"
       },
 
-      ".MathJax_Hover_Arrow": {
+      ".MathJax_Menu_Button .MathJax_Hover_Arrow": {
         position:"absolute",
-        width:"15px", height:"11px",
-        cursor:"pointer"
+        cursor:"pointer",
+        display:"inline-block",
+        border:"2px solid #AAA",
+        "border-radius":"4px",
+        "-webkit-border-radius": "4px",           // Safari and Chrome
+        "-moz-border-radius": "4px",              // Firefox
+        "-khtml-border-radius": "4px",            // Konqueror
+        "font-family":"'Courier New',Courier",
+        "font-size":"9px",
+        color:"#F0F0F0"
+      },
+      ".MathJax_Menu_Button .MathJax_Hover_Arrow span": {
+        display:"block",
+        "background-color":"#AAA",
+        border:"1px solid",
+        "border-radius":"3px",
+        "line-height":0,
+        padding:"4px"
+      },
+      ".MathJax_Hover_Arrow:hover": {
+        color:"white!important",
+        border:"2px solid #CCC!important"
+      },
+      ".MathJax_Hover_Arrow:hover span": {
+        "background-color":"#CCC!important"
       }
     }
   };
 
-  
+
   //
   //  Common event-handling code
   //
   var EVENT = ME.Event = {
-    
+
     LEFTBUTTON: 0,           // the event.button value for left button
     RIGHTBUTTON: 2,          // the event.button value for right button
     MENUKEY: "altKey",       // the event value for alternate context menu
 
+    /*************************************************************/
+    /*
+     *  Enum element for key codes.
+     */
+    KEY: {
+      RETURN: 13,
+      ESCAPE: 27,
+      SPACE: 32,
+      LEFT: 37,
+      UP: 38,
+      RIGHT: 39,
+      DOWN: 40
+    },
+
     Mousedown: function (event) {return EVENT.Handler(event,"Mousedown",this)},
     Mouseup:   function (event) {return EVENT.Handler(event,"Mouseup",this)},
     Mousemove: function (event) {return EVENT.Handler(event,"Mousemove",this)},
@@ -95,7 +131,7 @@
     Click:     function (event) {return EVENT.Handler(event,"Click",this)},
     DblClick:  function (event) {return EVENT.Handler(event,"DblClick",this)},
     Menu:      function (event) {return EVENT.Handler(event,"ContextMenu",this)},
-    
+
     //
     //  Call the output jax's event handler or the zoom handler
     //
@@ -107,7 +143,7 @@
       if (jax[type]) {return jax[type](event,math)}
       if (EXTENSION.MathZoom) {return EXTENSION.MathZoom.HandleEvent(event,type,math)}
     },
-    
+
     //
     //  Try to cancel the event in every way we can
     //
@@ -121,6 +157,16 @@
       return false;
     },
 
+    //
+    // Keydown event handler. Should only fire on Space key.
+    //
+    Keydown: function (event, math) {
+      if (!event) event = window.event;
+      if (event.keyCode === EVENT.KEY.SPACE) {
+        EVENT.ContextMenu(event, this);
+      };
+    },
+
     //
     //  Load the contextual menu code, if needed, and post the menu
     //
@@ -143,7 +189,7 @@
       }
 
       //
-      //  If the menu code is loaded, 
+      //  If the menu code is loaded,
       //    Check if localization needs loading;
       //    If not, post the menu, and return.
       //    Otherwise wait for the localization to load
@@ -156,18 +202,18 @@
         load = LOCALE.loadDomain("MathMenu");
         if (!load) {
           MENU.jax = jax;
-          var source = MENU.menu.Find("Show Math As").menu;
-	  source.items[0].name = jax.sourceMenuTitle;
-	  source.items[0].format = (jax.sourceMenuFormat||"MathML");
+          var source = MENU.menu.Find("Show Math As").submenu;
+          source.items[0].name = jax.sourceMenuTitle;
+          source.items[0].format = (jax.sourceMenuFormat||"MathML");
           source.items[1].name = INPUT[jax.inputJax].sourceMenuTitle;
           source.items[5].disabled = !INPUT[jax.inputJax].annotationEncoding;
 
-          // 
+          //
           // Try and find each known annotation format and enable the menu
           // items accordingly.
           //
           var annotations = source.items[2]; annotations.disabled = true;
-          var annotationItems = annotations.menu.items;
+          var annotationItems = annotations.submenu.items;
           annotationList = MathJax.Hub.Config.semanticsAnnotations;
           for (var i = 0, m = annotationItems.length; i < m; i++) {
             var name = annotationItems[i].name[1]
@@ -204,7 +250,7 @@
       );
       return EVENT.False(event);
     },
-    
+
     //
     //  Mousedown handler for alternate means of accessing menu
     //
@@ -221,26 +267,26 @@
         return JAX.ContextMenu(event,math,true);
       }
     },
-    
+
     ClearSelection: function () {
       if (ME.safariContextMenuBug) {setTimeout("window.getSelection().empty()",0)}
       if (document.selection) {setTimeout("document.selection.empty()",0)}
     },
-    
+
     getBBox: function (span) {
       span.appendChild(ME.topImg);
       var h = ME.topImg.offsetTop, d = span.offsetHeight-h, w = span.offsetWidth;
       span.removeChild(ME.topImg);
       return {w:w, h:h, d:d};
     }
-    
+
   };
-  
+
   //
   //  Handle hover "discoverability"
   //
   var HOVER = ME.Hover = {
-    
+
     //
     //  Check if we are moving from a non-MathJax element to a MathJax one
     //  and either start fading in again (if it is fading out) or start the
@@ -250,7 +296,7 @@
       if (SETTINGS.discoverable || SETTINGS.zoom === "Hover") {
         var from = event.fromElement || event.relatedTarget,
             to   = event.toElement   || event.target;
-        if (from && to && (from.isMathJax != to.isMathJax ||
+        if (from && to && (HUB.isMathJaxNode(from) !== HUB.isMathJaxNode(to) ||
                            HUB.getJaxFor(from) !== HUB.getJaxFor(to))) {
           var jax = this.getJaxFromMath(math);
           if (jax.hover) {HOVER.ReHover(jax)} else {HOVER.HoverTimer(jax,math)}
@@ -267,7 +313,7 @@
       if (SETTINGS.discoverable || SETTINGS.zoom === "Hover") {
         var from = event.fromElement || event.relatedTarget,
             to   = event.toElement   || event.target;
-        if (from && to && (from.isMathJax != to.isMathJax ||
+        if (from && to && (HUB.isMathJaxNode(from) !== HUB.isMathJaxNode(to) ||
                            HUB.getJaxFor(from) !== HUB.getJaxFor(to))) {
           var jax = this.getJaxFromMath(math);
           if (jax.hover) {HOVER.UnHover(jax)} else {HOVER.ClearHoverTimer()}
@@ -287,7 +333,7 @@
         return EVENT.False(event);
       }
     },
-    
+
     //
     //  Clear the old timer and start a new one
     //
@@ -298,7 +344,7 @@
     ClearHoverTimer: function () {
       if (this.hoverTimer) {clearTimeout(this.hoverTimer); delete this.hoverTimer}
     },
-    
+
     //
     //  Handle putting up the hover frame
     //
@@ -334,17 +380,17 @@
         ]]
       );
       var button = HTML.Element("span",{
-         isMathJax: true, id:jax.hover.id+"Menu",
+         isMathJax: true, id:jax.hover.id+"Menu", className:"MathJax_Menu_Button",
          style:{display:"inline-block", "z-index": 1, width:0, height:0, position:"relative"}
-        },[["img",{
+        },[["span",{
             className: "MathJax_Hover_Arrow", isMathJax: true, math: math,
-            src: CONFIG.button.src, onclick: this.HoverMenu, jax:JAX.id,
+            onclick: this.HoverMenu, jax:JAX.id,
             style: {
               left:this.Px(bbox.w+dx+dd+(bbox.x||0)+CONFIG.button.x),
               top:this.Px(-bbox.h-dy-dd-(bbox.y||0)-CONFIG.button.y),
               opacity:0, filter:"alpha(opacity=0)"
             }
-          }]]
+          },[["span",{isMathJax:true},"\u25BC"]]]]
       );
       if (bbox.width) {
         frame.style.width = button.style.width = bbox.width;
@@ -409,7 +455,7 @@
         jax.hover.timer = setTimeout(CALLBACK(["HoverFade",this,jax]),(delay||CONFIG.fadeDelay));
       }
     },
-    
+
     //
     //  Handle a click on the menu button
     //
@@ -417,7 +463,7 @@
       if (!event) {event = window.event}
       return OUTPUT[this.jax].ContextMenu(event,this.math,true);
     },
-    
+
     //
     //  Clear all hover timers
     //
@@ -427,7 +473,7 @@
       HOVER.ClearHoverTimer();
       delete jax.hover;
     },
-    
+
     //
     //  Make a measurement in pixels
     //
@@ -447,9 +493,9 @@
     }
 
   };
-  
+
   //
-  //  Handle touch events.  
+  //  Handle touch events.
   //
   //  Use double-tap-and-hold as a replacement for context menu event.
   //  Use double-tap as a replacement for double click.
@@ -458,7 +504,7 @@
 
     last: 0,          // time of last tap event
     delay: 500,       // delay time for double-click
-    
+
     //
     //  Check if this is a double-tap, and if so, start the timer
     //  for the double-tap and hold (to trigger the contextual menu)
@@ -472,9 +518,9 @@
         event.preventDefault();
       }
     },
-          
+
     //
-    //  Check if there is a timeout pending, i.e., we have a 
+    //  Check if there is a timeout pending, i.e., we have a
     //  double-tap and were waiting to see if it is held long
     //  enough for the menu.  Since we got the end before the
     //  timeout, it is a double-click, not a double-tap-and-hold.
@@ -490,7 +536,7 @@
         return EVENT.Handler((event.touches[0]||event.touch),"DblClick",this);
       }
     },
-        
+
     //
     //  If the timeout passes without an end event, we issue
     //  the contextual menu event.
@@ -499,18 +545,20 @@
       delete TOUCH.timeout; TOUCH.last = 0; TOUCH.up = false;
       return EVENT.Handler((event.touches[0]||event.touch),"ContextMenu",math);
     }
-    
+
   };
-  
-  //
-  //  Mobile screens are small, so use larger version of arrow
-  //
-  if (HUB.Browser.isMobile) {
-    var arrow = CONFIG.styles[".MathJax_Hover_Arrow"];
-    arrow.width = "25px"; arrow.height = "18px";
-    CONFIG.button.x = -6;
-  }
-  
+
+  /*
+   * //
+   * //  Mobile screens are small, so use larger version of arrow
+   * //
+   * if (HUB.Browser.isMobile) {
+   *   var arrow = CONFIG.styles[".MathJax_Hover_Arrow"];
+   *   arrow.width = "25px"; arrow.height = "18px";
+   *   CONFIG.button.x = -6;
+   * }
+   */
+
   //
   //  Set up browser-specific values
   //
@@ -533,7 +581,7 @@
       ME.noContextMenuBug = true;      // doesn't produce contextmenu event
     }
   });
-  
+
   //
   //  Used in measuring zoom and hover positions
   //
@@ -554,7 +602,7 @@
       haze["-moz-box-shadow"] = haze["-khtml-box-shadow"] =
         "0px 0px "+CONFIG.frame.hwidth+" "+CONFIG.frame.hcolor;
   };
-  
+
   //
   //  Queue the events needed for startup
   //
@@ -566,6 +614,6 @@
     ["Post",HUB.Startup.signal,"MathEvents Ready"],
     ["loadComplete",AJAX,"[MathJax]/extensions/MathEvents.js"]
   );
-  
+
 })(MathJax.Hub,MathJax.HTML,MathJax.Ajax,MathJax.Callback,
    MathJax.Localization,MathJax.OutputJax,MathJax.InputJax);
