@@ -18,7 +18,7 @@
  *
  *  ---------------------------------------------------------------------
  *  
- *  Copyright (c) 2010-2014 The MathJax Consortium
+ *  Copyright (c) 2010-2019 The MathJax Consortium
  * 
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -34,7 +34,7 @@
  */
 
 MathJax.Extension.jsMath2jax = {
-  version: "2.4.0",
+  version: "2.7.7",
   
   config: {
     preview: "TeX"    // Set to "none" to prevent preview strings from being inserted
@@ -73,10 +73,13 @@ MathJax.Extension.jsMath2jax = {
   },
   
   createPreview: function (node) {
+    var previewClass = MathJax.Hub.config.preRemoveClass;
     var preview = this.config.preview;
+    if (preview === "none") return;
+    if ((node.previousSibling||{}).className === previewClass) return;
     if (preview === "TeX") {preview = [this.filterPreview(node.innerHTML)]}
     if (preview) {
-      preview = MathJax.HTML.Element("span",{className: MathJax.Hub.config.preRemoveClass},preview);
+      preview = MathJax.HTML.Element("span",{className:previewClass},preview);
       node.parentNode.insertBefore(preview,node);
     }
   },
