@@ -9,7 +9,7 @@
  *
  *  ---------------------------------------------------------------------
  *  
- *  Copyright (c) 2015 The MathJax Consortium
+ *  Copyright (c) 2015-2019 The MathJax Consortium
  * 
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -25,7 +25,7 @@
  */
 
 MathJax.Hub.Register.StartupHook("CommonHTML Jax Ready",function () {
-  var VERSION = "2.6.0";
+  var VERSION = "2.7.7";
   var MML = MathJax.ElementJax.mml,
       CONFIG = MathJax.Hub.config,
       CHTML = MathJax.OutputJax.CommonHTML,
@@ -59,11 +59,6 @@ MathJax.Hub.Register.StartupHook("CommonHTML Jax Ready",function () {
       //
       this.CHTMLgetBoxSizes(values,state);
       this.CHTMLgetAttributes(values,state);
-      if (values.equalrows) {
-        state.HD = true;
-        state.HH = Math.max.apply(Math,state.H);
-        state.DD = Math.max.apply(Math,state.D);
-      }
       this.CHTMLadjustCells(values,state);
       if (values.frame) table.style.border = state.t+" "+values.frame;
       this.CHTMLalignV(values,state,node);
@@ -98,8 +93,8 @@ MathJax.Hub.Register.StartupHook("CommonHTML Jax Ready",function () {
     CHTMLgetBoxSizes: function (values,state) {
       var LH = CHTML.FONTDATA.lineH * values.useHeight,
           LD = CHTML.FONTDATA.lineD * values.useHeight;
-      var H = [], D = [], W = [], J = -1;
-      for (var i = 0, m = this.data.length; i < m; i++) {
+      var H = [], D = [], W = [], J = -1, i, m;
+      for (i = 0, m = this.data.length; i < m; i++) {
         var  row = this.data[i], s = (row.type === "mtr" ? 0 : LABEL);
         H[i] = LH; D[i] = LD;
         for (var j = s, M = row.data.length + s; j < M; j++) {
@@ -110,6 +105,12 @@ MathJax.Hub.Register.StartupHook("CommonHTML Jax Ready",function () {
           if (cbox.w > W[j]) W[j] = cbox.w;
         }
       }
+      if (values.equalrows) {
+        state.HD = true;
+        var HH = Math.max.apply(Math,H);
+        var DD = Math.max.apply(Math,D);
+        for (i = 0, m = H.length; i < m; i++) {H[i] = HH; D[i] = DD}
+      }
       state.H = H; state.D = D; state.W = W, state.J = J;
     },
     //
@@ -187,21 +188,28 @@ MathJax.Hub.Register.StartupHook("CommonHTML Jax Ready",function () {
           CALIGN = state.CALIGN, RALIGN = state.RALIGN,
           RCALIGN = state.RCALIGN;
       CSPACE[state.J] *= 2; RSPACE[ROWS.length-1] *= 2; // since halved below
-      var LH = CHTML.FONTDATA.lineH * values.useHeight,
-          LD = CHTML.FONTDATA.lineD * values.useHeight;
-      var T = "0", B, R, L, border, cbox, align;
-      if (values.fspace) T = CHTML.Em(state.FSPACE[1]);
+      var T = "0", B, R, L, border, cbox, align, lastB = 0;
+      if (values.fspace) {
+        lastB = state.FSPACE[1];
+        T = CHTML.Em(state.FSPACE[1]);
+      }
+      state.RHD = []; state.RH = [];
       for (var i = 0, m = ROWS.length; i < m; i++) {
         var row = ROWS[i], rdata = this.data[i];
         //
         //  Space and borders between rows
         //
         B = RSPACE[i]/2; border = null; L = "0";
-        if (RLINES[i] !== MML.LINES.NONE) {
-          border = state.t+" "+RLINES[i];
-          B -= 1/CHTML.em/2;
+        if (RLINES[i] !== MML.LINES.NONE && RLINES[i] !== "") border = state.t+" "+RLINES[i];
+        if (border || (CLINES[j] !== MML.LINES.NONE && CLINES[j] !== "")) {
+          while (row.length <= state.J) {
+            row.push(CHTML.addElement(row.node,"mjx-mtd",null,[['span']]));
+          }
         }
-        B = CHTML.Em(Math.max(0,B));
+        state.RH[i] = lastB + state.H[i];                 // distance to baseline in row
+        lastB = Math.max(0,B);
+        state.RHD[i] = state.RH[i] + lastB + state.D[i];  // total height of row
+        B = CHTML.Em(lastB);
         //
         //  Frame space for initial cell
         //
@@ -211,7 +219,8 @@ MathJax.Hub.Register.StartupHook("CommonHTML Jax Ready",function () {
         //
         for (var j = 0, M = row.length; j < M; j++) {
           var s = (rdata.type === "mtr" ? 0 : LABEL);
-          cell = row[j].style; cbox = rdata.data[j-s].CHTML;
+          var mtd = rdata.data[j-s] || {CHTML: CHTML.BBOX.zero()};
+          var cell = row[j].style; cbox = mtd.CHTML;
           //
           //  Space and borders between columns
           //
@@ -221,36 +230,35 @@ MathJax.Hub.Register.StartupHook("CommonHTML Jax Ready",function () {
             R -= 1/CHTML.em/2;
           }
           R = CHTML.Em(Math.max(0,R));
-          cell.padding = T+" "+R+" "+B+" "+L;
+          cell.padding = T+" "+R+" 0px "+L;
           if (border) cell.borderBottom = border;
           L = R;
           //
-          //  Handle vertical and horizontal alignment
+          //  Handle vertical alignment
           //
-          align = (rdata.data[j-s].rowalign||this.data[i].rowalign||RALIGN[i]);
-          align = ({top:"top", bottom:"bottom", center:"middle"})[align];
-          if (align) cell.verticalAlign = align;
-          align = (rdata.data[j-s].columnalign||RCALIGN[i][j]||CALIGN[j]);
-          if (align !== MML.ALIGN.CENTER) cell.textAlign = align;
-          //
-          //  Equal heights forced by adding an element of the proper size
-          //  (setting style.height seems to work very strangely)
-          //
-          if (state.HD && j === 0) {
-            CHTML.addElement(row[j].parentNode,"mjx-mtd",{style:{padding:T+" 0 "+B}},
-              [["mjx-box",{style:{
-                height:CHTML.Em(state.HH+state.DD),
-                "vertical-align":CHTML.Em(-state.DD)
-              }}]]
-            );
+          align = (mtd.rowalign||(this.data[i]||{}).rowalign||RALIGN[i]);
+          var H = Math.max(1,cbox.h), D = Math.max(.2,cbox.d),
+              HD = (state.H[i]+state.D[i]) - (H+D),
+              child = row[j].firstChild.style;
+          if (align === MML.ALIGN.TOP) {
+            if (HD) child.marginBottom = CHTML.Em(HD);
+            cell.verticalAlign = "top";
+          } else if (align === MML.ALIGN.BOTTOM) {
+            cell.verticalAlign = "bottom";
+            if (HD) child.marginTop = CHTML.Em(HD);
+          } else if (align === MML.ALIGN.CENTER) {
+            if (HD) child.marginTop = child.marginBottom = CHTML.Em(HD/2);
+            cell.verticalAlign = "middle";
+          } else {
+            if (H !== state.H[i]) child.marginTop = CHTML.Em(state.H[i]-H);
           }
           //
-          //  Pad cells that are too short
+          //  Handle horizontal alignment
           //
-          cell = row[j].firstChild.style;
-          if (cbox.h < LH) cell.marginTop    = CHTML.Em(LH-cbox.h);
-          if (cbox.d < LD) cell.marginBottom = CHTML.Em(LD-cbox.d);
+          align = (mtd.columnalign||RCALIGN[i][j]||CALIGN[j]);
+          if (align !== MML.ALIGN.CENTER) cell.textAlign = align;
         }
+        row.node.style.height = CHTML.Em(state.RHD[i]);
         T = B;
       }
       CSPACE[state.J] /= 2; RSPACE[ROWS.length-1] /= 2; // back to normal
@@ -278,9 +286,8 @@ MathJax.Hub.Register.StartupHook("CommonHTML Jax Ready",function () {
       var T = 0, B = 0, a = CHTML.TEX.axis_height;
       if (values.fspace) T += state.FSPACE[1];
       if (values.frame) {T += 2/CHTML.em; B += 1/CHTML.em}
-      var h = state.HH, d = state.DD;
       for (var i = 0; i < M; i++) {
-        if (!state.HD) {h = H[i]; d = D[i]}
+        var h = H[i], d = D[i];
         T += h + d + RSPACE[i];
         if (n) {
           if (i === n-1) {
@@ -402,8 +409,10 @@ MathJax.Hub.Register.StartupHook("CommonHTML Jax Ready",function () {
       //  Set variable width on DOM nodes
       //
       if (relWidth) {
-        this.CHTML.pwidth = values.width; this.CHTML.mwidth = CHTML.Em(TW);
-        node.style.width = node.firstChild.style.width = "100%";
+        node.style.width = this.CHTML.pwidth = "100%";
+        this.CHTML.mwidth = CHTML.Em(TW);
+        node.firstChild.style.width = values.width;
+        node.firstChild.style.margin = "auto";
       }
     },
     //
@@ -412,10 +421,9 @@ MathJax.Hub.Register.StartupHook("CommonHTML Jax Ready",function () {
     CHTMLstretchCells: function (values,state) {
       var ROWS = state.rows, H = state.H, D = state.D, W = state.W,
           J = state.J, M = ROWS.length-1;
-      var h = state.HH, d = state.DD;
       for (var i = 0; i <= M; i++) {
         var row = ROWS[i], rdata = this.data[i];
-        if (!state.HD) {h = H[i]; d = D[i]}
+        var h = H[i], d = D[i];
         for (var j = 0; j <= J; j++) {
           var cell = row[j], cdata = rdata.data[j];
           if (!cdata) continue;
@@ -458,7 +466,7 @@ MathJax.Hub.Register.StartupHook("CommonHTML Jax Ready",function () {
       var box = CHTML.addElement(node,"mjx-box",{
         style:{width:"100%","text-align":indent.indentalign}
       }); box.appendChild(table);
-      var labels = CHTML.Element("mjx-stack");
+      var labels = CHTML.Element("mjx-itable");
       table.style.display = "inline-table"; if (!table.style.width) table.style.width = "auto";
       labels.style.verticalAlign = "top";
       table.style.verticalAlign = CHTML.Em(state.T-state.B-state.H[0]);
@@ -486,21 +494,18 @@ MathJax.Hub.Register.StartupHook("CommonHTML Jax Ready",function () {
       //
       //  Vertically align the labels with their rows
       //
-      var LABELS = state.labels, T = 0, H = state.H, D = state.D, RSPACE = state.RSPACE;
+      var LABELS = state.labels, T = 0;
       if (values.fspace) T = state.FSPACE[0] + (values.frame ? 1/CHTML.em : 0);
-      var h = state.HH, d = state.DD;
       for (var i = 0, m = LABELS.length; i < m; i++) {
-        if (!state.HD) {h = H[i]; d = D[i]}
         if (LABELS[i] && this.data[i].data[0]) {
           labels.appendChild(LABELS[i]);
           var lbox = this.data[i].data[0].CHTML;
-          T += h - lbox.h;
-          if (T) LABELS[i].style.marginTop = CHTML.Em(T);
-          T = d - lbox.d;
+          T = state.RH[i] - Math.max(1,lbox.h);
+          if (T) LABELS[i].firstChild.firstChild.style.marginTop = CHTML.Em(T);
+          LABELS[i].style.height = CHTML.Em(state.RHD[i]);
         } else {
-          T += h + d;
+          CHTML.addElement(labels,"mjx-label",{style:{height:CHTML.Em(state.RHD[i])}});
         }
-        T += RSPACE[i];
       }
       //
       //  Propagate full-width equations, and reserve room for equation plus label
@@ -522,7 +527,7 @@ MathJax.Hub.Register.StartupHook("CommonHTML Jax Ready",function () {
       //  Add a new row with no label
       //
       if (!options) options = {rows:[],labels:[]};
-      var row = []; options.rows.push(row);
+      var row = []; options.rows.push(row); row.node = node;
       options.labels.push(null);
       //
       //  Add the cells to the row
@@ -546,7 +551,7 @@ MathJax.Hub.Register.StartupHook("CommonHTML Jax Ready",function () {
       //  Add a new row, and get the label
       //
       if (!options) options = {rows:[],labels:[]};
-      var row = []; options.rows.push(row);
+      var row = []; options.rows.push(row); row.node = node;
       var label = CHTML.Element("mjx-label"); options.labels.push(label);
       this.CHTMLaddChild(label,0,options);
       if (this.data[0]) options.labeled = true;
@@ -563,6 +568,7 @@ MathJax.Hub.Register.StartupHook("CommonHTML Jax Ready",function () {
   MML.mtd.Augment({
     toCommonHTML: function (node,options) {
       node = this.CHTMLdefaultNode(node,options);
+      CHTML.addElement(node.firstChild,"mjx-strut");  // forces height to 1em (we adjust later)
       //
       //  Determine if this is stretchy or not
       //
