@@ -4,7 +4,7 @@
  *  
  *  Initializes the HTML-CSS OutputJax to use the Gyre-Pagella fonts
 
- *  Copyright (c) 2013-2015 The MathJax Consortium
+ *  Copyright (c) 2013-2019 The MathJax Consortium
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -21,7 +21,7 @@
 
 (function (HTMLCSS,MML,AJAX) {
 
-    var VERSION = "2.5.0";
+  var VERSION = "2.7.7";
 
   var ALPHABETS = "GyrePagellaMathJax_Alphabets",
       ARROWS = "GyrePagellaMathJax_Arrows",
@@ -141,7 +141,7 @@
              offsetA: 0x1D670,
              offsetN: 0x1D7F6
           },
-        "-Gyre-Pagella-variant": {fonts: [VARIANTS,MAIN,NORMAL,MONOSPACE,LATIN,ALPHABETS,MARKS,ARROWS,OPERATORS,SYMBOLS,SHAPES,MISC,NONUNICODE,SIZE1]},
+          "-Gyre-Pagella-variant": {fonts: [VARIANTS,MAIN,NORMAL,MONOSPACE,LATIN,ALPHABETS,MARKS,ARROWS,OPERATORS,SYMBOLS,SHAPES,MISC,NONUNICODE,SIZE1]},
           "-tex-caligraphic": {fonts: [MAIN,NORMAL,MONOSPACE,LATIN,ALPHABETS,MARKS,ARROWS,OPERATORS,SYMBOLS,SHAPES,MISC,VARIANTS,NONUNICODE,SIZE1], italic: true},
           "-tex-oldstyle": {fonts: [MAIN,NORMAL,MONOSPACE,LATIN,ALPHABETS,MARKS,ARROWS,OPERATORS,SYMBOLS,SHAPES,MISC,VARIANTS,NONUNICODE,SIZE1]},
           "-tex-caligraphic-bold": {fonts: [MAIN,NORMAL,MONOSPACE,LATIN,ALPHABETS,MARKS,ARROWS,OPERATORS,SYMBOLS,SHAPES,MISC,VARIANTS,NONUNICODE,SIZE1], italic: true, bold: true},
@@ -160,9 +160,10 @@
            remap: {0x03F5: 52, 0x03D1: 53, 0x03F0: 54, 0x03D5: 55, 0x03F1: 56, 0x03D6: 57, 0x03F4: 17}}
       ],
 
-      RULECHAR: 0x0305,
+      RULECHAR: 0x2212,
 
       REMAP: {
+        0xA: 0x20,
         0x25C2: 0x25C0,
         0x3008: 0x27E8,
         0x3009: 0x27E9,
@@ -207,7 +208,7 @@
           HW: [[0.828,MAIN], [0.988,SIZE1], [1.180,SIZE2], [1.410,SIZE3], [1.686,SIZE4], [2.018,SIZE5], [2.416,SIZE6], [2.612,SIZE6,1.081]],
           stretch: {bot:[0x23A0,SYMBOLS], ext:[0x239F,SYMBOLS], top:[0x239E,SYMBOLS]}
         },
-        0x2D: {alias: 0x305, dir: H},
+        0x2D: {alias: 0x2212, dir: H},
         0x2F:
         {
           dir: V,
@@ -259,7 +260,7 @@
         0x7E: {alias: 0x303, dir: H},
         0xAF: {alias: 0x332, dir: H},
         0x2C6: {alias: 0x302, dir: H},
-        0x2C9: {alias: 0x305, dir: H},
+        0x2C9: {alias: 0x2212, dir: H},
         0x2DC: {alias: 0x303, dir: H},
         0x302:
         {
@@ -297,15 +298,15 @@
         },
         0x333: EXTRAH,
         0x33F: EXTRAH,
-        0x2015: {alias: 0x305, dir: H},
+        0x2015: {alias: 0x2212, dir: H},
         0x2016:
         {
           dir: V,
           HW: [[0.800,MAIN], [0.960,SIZE1], [1.152,SIZE2], [1.382,SIZE3], [1.658,SIZE4], [1.990,SIZE5], [2.388,SIZE6]],
           stretch: {bot:[0xE12A,SIZE6], ext:[0xE12B,SIZE6], top:[0xE12C,SIZE6]}
         },
-        0x2017: {alias: 0x305, dir: H},
-        0x203E: {alias: 0x305, dir: H},
+        0x2017: {alias: 0x2212, dir: H},
+        0x203E: {alias: 0x2212, dir: H},
         0x2044:
         {
           dir: V,
@@ -477,8 +478,8 @@
         0x2212:
         {
           dir: H,
-          HW: [[0.600,MAIN]],
-          stretch: {left:[0xE127,SIZE6], rep:[0xE128,SIZE6], right:[0xE129,SIZE6]}
+          HW: [],
+          stretch: {rep:[0x2212,MAIN,0,0,0,-.27,-.28]}
         },
         0x2215: {alias: 0x2044, dir: V},
         0x221A:
@@ -542,6 +543,9 @@
           HW: [[0.820,MAIN], [0.980,SIZE1], [1.172,SIZE2], [1.402,SIZE3], [1.678,SIZE4], [2.010,SIZE5], [2.408,SIZE6], [2.612,SIZE6,1.085]],
           stretch: {bot:[0x23A6,SYMBOLS], ext:[0x23A5,SYMBOLS]}
         },
+        0x2312: {alias: 0x23DC, dir:H},
+        0x2322: {alias: 0x23DC, dir:H},
+        0x2323: {alias: 0x23DD, dir:H},
         0x2329:
         {
           dir: V,
@@ -558,7 +562,7 @@
           HW: [[0.596,SYMBOLS]],
           stretch: {ext:[0x23AA,SYMBOLS]}
         },
-        0x23AF: {alias: 0x305, dir: H},
+        0x23AF: {alias: 0x2212, dir: H},
         0x23B0:
         {
           dir: V,
@@ -595,7 +599,7 @@
         },
         0x23E0: EXTRAH,
         0x23E1: EXTRAH,
-        0x2500: {alias: 0x305, dir: H},
+        0x2500: {alias: 0x2212, dir: H},
         0x27A1: EXTRAH,
         0x27E6: EXTRAV,
         0x27E7: EXTRAV,
@@ -670,6 +674,10 @@
 
     }
   });
+  MathJax.Hub.Register.LoadHook(HTMLCSS.fontDir+"/Main/Regular/Main.js",function () {
+    HTMLCSS.FONTDATA.FONTS[MAIN][0x2212][0] = HTMLCSS.FONTDATA.FONTS[MAIN][0x002B][0]; // - needs height and depth of +
+    HTMLCSS.FONTDATA.FONTS[MAIN][0x2212][1] = HTMLCSS.FONTDATA.FONTS[MAIN][0x002B][1]; // - needs height and depth of +
+  });
   MathJax.Hub.Register.LoadHook(HTMLCSS.fontDir+"/Size1/Regular/Main.js",function () {
     var i;
     for (i = 0x222B; i <= 0x222D; i++) {
