@@ -4,7 +4,7 @@
  *  
  *  Adds extra stretchy characters to the STIX-Web fonts
 
- *  Copyright (c) 2013-2015 The MathJax Consortium
+ *  Copyright (c) 2013-2019 The MathJax Consortium
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -20,11 +20,12 @@
  */
 
 (function (HTMLCSS) {
-  var VERSION = "2.6.0";
+  var VERSION = "2.7.7";
 
   var DELIMITERS = HTMLCSS.FONTDATA.DELIMITERS;
 
   var H = "H", V = "V";
+  var ARROWREP = [0x2212,MAIN,0,0,0,-.26,-.26];
 
   var ALPHABETSBOLDITALIC = "STIXMathJax_Alphabets-bold-italic",
       ALPHABETSBOLD = "STIXMathJax_Alphabets-bold",
@@ -162,7 +163,7 @@
       {
         dir: H,
         HW: [[0.786,MAIN]],
-        stretch: {left:[0x219E,MAIN], rep:[0x2212,MAIN]}
+        stretch: {left:[0x219E,MAIN], rep:ARROWREP}
       },
       0x219F:
       {
@@ -174,7 +175,7 @@
       {
         dir: H,
         HW: [[0.786,MAIN]],
-        stretch: {right:[0x21A0,MAIN], rep:[0x2212,MAIN]}
+        stretch: {right:[0x21A0,MAIN], rep:ARROWREP}
       },
       0x21A1:
       {
@@ -216,13 +217,13 @@
       {
         dir: H,
         HW: [[0.786,MAIN]],
-        stretch: {left:[0x2190,MAIN], rep:[0x2212,MAIN], right:[0xE0B5,ARROWS]}
+        stretch: {left:[0x2190,MAIN], rep:ARROWREP, right:[0xE0B5,ARROWS]}
       },
       0x21AA:
       {
         dir: H,
         HW: [[0.786,MAIN]],
-        stretch: {left:[0xE0B4,ARROWS], rep:[0x2212,MAIN], right:[0x2192,MAIN]}
+        stretch: {left:[0xE0B4,ARROWS], rep:ARROWREP, right:[0x2192,MAIN]}
       },
       0x21B0:
       {
@@ -294,7 +295,7 @@
       {
         dir: H,
         HW: [[0.847,MAIN]],
-        stretch: {right:[0x21C1,MAIN], rep:[0x2212,MAIN]}
+        stretch: {right:[0x21C1,MAIN], rep:ARROWREP}
       },
       0x21C2:
       {
@@ -360,31 +361,31 @@
       {
         dir: H,
         HW: [[0.806,ARROWS]],
-        stretch: {left:[0x21E4,ARROWS], rep:[0x2212,MAIN]}
+        stretch: {left:[0x21E4,ARROWS], rep:ARROWREP}
       },
       0x21E5:
       {
         dir: H,
         HW: [[0.806,ARROWS]],
-        stretch: {right:[0x21E5,ARROWS], rep:[0x2212,MAIN]}
+        stretch: {right:[0x21E5,ARROWS], rep:ARROWREP}
       },
       0x21FD:
       {
         dir: H,
         HW: [[0.806,ARROWS]],
-        stretch: {left:[0x21FD,ARROWS], rep:[0x2212,MAIN]}
+        stretch: {left:[0x21FD,ARROWS], rep:ARROWREP}
       },
       0x21FE:
       {
         dir: H,
         HW: [[0.806,ARROWS]],
-        stretch: {right:[0x21FE,ARROWS], rep:[0x2212,MAIN]}
+        stretch: {right:[0x21FE,ARROWS], rep:ARROWREP}
       },
       0x21FF:
       {
         dir: H,
         HW: [[0.886,ARROWS]],
-        stretch: {left:[0x21FD,ARROWS], rep:[0x2212,MAIN], right:[0x21FE,ARROWS]}
+        stretch: {left:[0x21FD,ARROWS], rep:ARROWREP, right:[0x21FE,ARROWS]}
       },
       0x220F:
       {
@@ -415,9 +416,9 @@
       },
       0x222B:
       {
-        dir: H,
+        dir: V,
         HW: [[0.607,MAIN], [0.979,SIZE1]],
-        stretch: {top:[0xE03C,SIZE5], rep:[0xE03D,SIZE5], bot:[0xE03E,SIZE5]}
+        stretch: {top:[0xE03C,SIZE5], ext:[0xE03D,SIZE5], bot:[0xE03E,SIZE5]}
       },
       0x222C:
       {
@@ -609,7 +610,7 @@
       {
         dir: H,
         HW: [[0.850,ARROWS]],
-        stretch: {left:[0x21BC,MAIN], rep:[0x2212,MAIN], right:[0x21C0,MAIN]}
+        stretch: {left:[0x21BC,MAIN], rep:ARROWREP, right:[0x21C0,MAIN]}
       },
       0x294F:
       {
@@ -621,7 +622,7 @@
       {
         dir: H,
         HW: [[0.850,ARROWS]],
-        stretch: {left:[0x21BD,MAIN], rep:[0x2212,MAIN], right:[0x21C1,MAIN]}
+        stretch: {left:[0x21BD,MAIN], rep:ARROWREP, right:[0x21C1,MAIN]}
       },
       0x2951:
       {
@@ -633,13 +634,13 @@
       {
         dir: H,
         HW: [[0.816,ARROWS]],
-        stretch: {left:[0x2952,ARROWS], rep:[0x2212,MAIN]}
+        stretch: {left:[0x2952,ARROWS], rep:ARROWREP}
       },
       0x2953:
       {
         dir: H,
         HW: [[0.816,ARROWS]],
-        stretch: {right:[0x2953,ARROWS], rep:[0x2212,MAIN]}
+        stretch: {right:[0x2953,ARROWS], rep:ARROWREP}
       },
       0x2954:
       {
@@ -657,13 +658,13 @@
       {
         dir: H,
         HW: [[0.816,ARROWS]],
-        stretch: {left:[0x2956,ARROWS], rep:[0x2212,MAIN]}
+        stretch: {left:[0x2956,ARROWS], rep:ARROWREP}
       },
       0x2957:
       {
         dir: H,
         HW: [[0.816,ARROWS]],
-        stretch: {right:[0x2957,ARROWS], rep:[0x2212,MAIN]}
+        stretch: {right:[0x2957,ARROWS], rep:ARROWREP}
       },
       0x2958:
       {
@@ -681,13 +682,13 @@
       {
         dir: H,
         HW: [[0.816,ARROWS]],
-        stretch: {left:[0x21BC,MAIN], rep:[0x2212,MAIN], right:[0x22A3,MAINBOLD,0.000,0.100,0.600]}
+        stretch: {left:[0x21BC,MAIN], rep:ARROWREP, right:[0x22A3,MAINBOLD,0.000,0.100,0.600]}
       },
       0x295B:
       {
         dir: H,
         HW: [[0.816,ARROWS]],
-        stretch: {left:[0xE0B6,ARROWS], rep:[0x2212,MAIN], right:[0x21C0,MAIN]}
+        stretch: {left:[0xE0B6,ARROWS], rep:ARROWREP, right:[0x21C0,MAIN]}
       },
       0x295C:
       {
@@ -705,13 +706,13 @@
       {
         dir: H,
         HW: [[0.816,ARROWS]],
-        stretch: {left:[0x21BD,MAIN], rep:[0x2212,MAIN], right:[0x22A3,MAINBOLD,0.000,0.100,0.600]}
+        stretch: {left:[0x21BD,MAIN], rep:ARROWREP, right:[0x22A3,MAINBOLD,0.000,0.100,0.600]}
       },
       0x295F:
       {
         dir: H,
         HW: [[0.816,ARROWS]],
-        stretch: {left:[0xE0B6,ARROWS], rep:[0x2212,MAIN], right:[0x21C1,MAIN]}
+        stretch: {left:[0xE0B6,ARROWS], rep:ARROWREP, right:[0x21C1,MAIN]}
       },
       0x2960:
       {
