@@ -9,7 +9,7 @@
  *
  *  ---------------------------------------------------------------------
  *  
- *  Copyright (c) 2011-2014 The MathJax Consortium
+ *  Copyright (c) 2011-2019 The MathJax Consortium
  * 
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -25,7 +25,7 @@
  */
 
 MathJax.Hub.Register.StartupHook("SVG Jax Ready",function () {
-  var VERSION = "2.4.0";
+  var VERSION = "2.7.7";
   var MML = MathJax.ElementJax.mml,
       SVG = MathJax.OutputJax.SVG,
       BBOX = SVG.BBOX;
@@ -41,7 +41,8 @@ MathJax.Hub.Register.StartupHook("SVG Jax Ready",function () {
                                   "align","useHeight","width","side","minlabelspacing");
       //  Handle relative width as fixed width in relation to container
       if (values.width.match(/%$/))
-        {svg.width = values.width = Math.floor(SVG.cwidth*parseFloat(values.width)/100)+"px"}
+        {svg.width = values.width = SVG.Em((SVG.cwidth/1000)*(parseFloat(values.width)/100))}
+
       var mu = this.SVGgetMu(svg);
       var LABEL = -1;
 
@@ -164,7 +165,7 @@ MathJax.Hub.Register.StartupHook("SVG Jax Ready",function () {
       var Y, fY, n = "";
       if (typeof(values.align) !== "string") {values.align = String(values.align)}
       if (values.align.match(/(top|bottom|center|baseline|axis)( +(-?\d+))?/))
-        {n = RegExp.$3; values.align = RegExp.$1} else {values.align = this.defaults.align}
+        {n = RegExp.$3||""; values.align = RegExp.$1} else {values.align = this.defaults.align}
       if (n !== "") {
         //
         //  Find the height of the given row
@@ -204,9 +205,9 @@ MathJax.Hub.Register.StartupHook("SVG Jax Ready",function () {
 
         //  Get total width minus column spacing
         WW = SVG.length2em(values.width,mu);
-        for (i = 0, m = Math.min(J+1,CSPACE.length); i < m; i++) {WW -= CSPACE[i]}
+        for (i = 0, m = Math.min(J,CSPACE.length); i < m; i++) {WW -= CSPACE[i]}
         //  Determine individual column widths
-        WW /= J+1;
+        WW /= J;
         for (i = 0, m = Math.min(J+1,CWIDTH.length); i < m; i++) {W[i] = WW}
       } else {
         //
@@ -225,8 +226,8 @@ MathJax.Hub.Register.StartupHook("SVG Jax Ready",function () {
         if (values.width === "auto") {
           if (WP > .98) {Wf = Wp/(Wt+Wp); WW = Wt + Wp} else {WW = Wt / (1-WP)}
         } else {
-          WW = SVG.length2em(values.width,mu);
-          for (i = 0, m = Math.min(J+1,CSPACE.length); i < m; i++) {WW -= CSPACE[i]}
+          WW = Math.max(Wt + Wp, SVG.length2em(values.width,mu));
+          for (i = 0, m = Math.min(J,CSPACE.length); i < m; i++) {WW -= CSPACE[i]}
         }
         //  Determine the relative column widths
         for (i = 0, m = P.length; i < m; i++) {
@@ -307,7 +308,7 @@ MathJax.Hub.Register.StartupHook("SVG Jax Ready",function () {
       y = Y - lw/2;
       for (i = 0, m = A.length-1; i < m; i++) {
         dy = Math.max(0,D[i]+H[i+1]+RSPACE[i]);
-        if (RLINES[i] !== "none")
+        if (RLINES[i] !== MML.LINES.NONE && RLINES[i] !== "")
           {svg.Add(BBOX.HLINE(fW,lw,RLINES[i]),0,y-D[i]-(dy-D[i]-H[i+1])/2)}
         y -= dy;
       }
@@ -323,25 +324,40 @@ MathJax.Hub.Register.StartupHook("SVG Jax Ready",function () {
       //  Place the labels, if any
       //
       if (C[LABEL]) {
+        svg.tw = Math.max(svg.w,svg.r) - Math.min(0,svg.l);
         var indent = this.getValues("indentalignfirst","indentshiftfirst","indentalign","indentshift");
         if (indent.indentalignfirst !== MML.INDENTALIGN.INDENTALIGN) {indent.indentalign = indent.indentalignfirst}
         if (indent.indentalign === MML.INDENTALIGN.AUTO) {indent.indentalign = this.displayAlign}
         if (indent.indentshiftfirst !== MML.INDENTSHIFT.INDENTSHIFT) {indent.indentshift = indent.indentshiftfirst}
-        if (indent.indentshift === "auto") {indent.indentshift = this.displayIndent}
-        var shift = (indent.indentshift ? SVG.length2em(indent.indentshift,mu) : 0);
-        var labelshift = SVG.length2em(values.minlabelspacing,mu);
-        var eqn = svg; svg = this.SVG();
+        if (indent.indentshift === "auto" || indent.indentshift === "") {indent.indentshift = "0"}
+        var shift = SVG.length2em(indent.indentshift,mu,SVG.cwidth);
+        var labelspace = SVG.length2em(values.minlabelspacing,mu,SVG.cwidth);
+        var labelW = labelspace + C[LABEL].w, labelshift = 0, tw = svg.w;
+        var dIndent = SVG.length2em(this.displayIndent,mu,SVG.cwidth);
+        s = (CALIGN[LABEL] === MML.INDENTALIGN.RIGHT ? -1 : 1);
         if (indent.indentalign === MML.INDENTALIGN.CENTER) {
-          svg.w = svg.r = SVG.length2em(SVG.cwidth+"px"); shift = 0; svg.hasIndent = true;
-        } else if (CALIGN[LABEL] !== indent.indentalign) {
-          svg.w = svg.r = SVG.length2em(SVG.cwidth+"px") - shift - labelshift;
-          shift = labelshift = 0;
+          var dx = (SVG.cwidth-tw)/2; shift += dIndent;
+          if (labelW + s*labelshift > dx + s*shift) {
+            indent.indentalign = CALIGN[LABEL];
+            shift = s*(labelW + s*labelshift); tw += labelW + Math.max(0,shift);
+          }
+        } else if (CALIGN[LABEL] === indent.indentalign) {
+          if (dIndent < 0) {labelshift = s*dIndent; dIndent = 0}
+          shift += s*dIndent; if (labelW > s*shift) shift = s*labelW; shift += labelshift;
+          tw += s*shift;
         } else {
-          svg.w = svg.r = eqn.w + shift;
-          svg.hasIndent = true;
+          shift -= s*dIndent;
+          if (tw - s*shift + labelW > SVG.cwidth) {
+            shift = s*(tw + labelW - SVG.cwidth);
+            if (s*shift > 0) {tw = SVG.cwidth + s*shift; shift = 0}
+          }
         }
-        svg.Align(eqn,indent.indentalign,shift,0);
-        svg.Align(C[LABEL],CALIGN[LABEL],labelshift,0);
+        var eqn = svg; svg = this.SVG();
+        svg.hasIndent = true;
+        svg.w = svg.r = Math.max(tw,SVG.cwidth); 
+        svg.Align(C[LABEL],CALIGN[LABEL],0,0,labelshift);
+        svg.Align(eqn,indent.indentalign,0,0,shift);
+        svg.tw = tw;
       }
       
       this.SVGsaveData(svg);
