@@ -4,7 +4,7 @@
  *  
  *  Initializes the SVG OutputJax to use the Gyre-Pagella fonts
 
- *  Copyright (c) 2013-2015 The MathJax Consortium
+ *  Copyright (c) 2013-2019 The MathJax Consortium
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -21,7 +21,7 @@
 
 (function (SVG,MML,AJAX,HUB) {
 
-    var VERSION = "2.6.0";
+  var VERSION = "2.7.7";
 
   var ALPHABETS = "GyrePagellaMathJax_Alphabets",
       ARROWS = "GyrePagellaMathJax_Arrows",
@@ -138,7 +138,7 @@
              offsetA: 0x1D670,
              offsetN: 0x1D7F6
           },
-        "-Gyre-Pagella-variant": {fonts: [VARIANTS,MAIN,NORMAL,MONOSPACE,LATIN,ALPHABETS,MARKS,ARROWS,OPERATORS,SYMBOLS,SHAPES,MISC,NONUNICODE,SIZE1]},
+          "-Gyre-Pagella-variant": {fonts: [VARIANTS,MAIN,NORMAL,MONOSPACE,LATIN,ALPHABETS,MARKS,ARROWS,OPERATORS,SYMBOLS,SHAPES,MISC,NONUNICODE,SIZE1]},
           "-tex-caligraphic": {fonts: [MAIN,NORMAL,MONOSPACE,LATIN,ALPHABETS,MARKS,ARROWS,OPERATORS,SYMBOLS,SHAPES,MISC,VARIANTS,NONUNICODE,SIZE1], italic: true},
           "-tex-oldstyle": {fonts: [MAIN,NORMAL,MONOSPACE,LATIN,ALPHABETS,MARKS,ARROWS,OPERATORS,SYMBOLS,SHAPES,MISC,VARIANTS,NONUNICODE,SIZE1]},
           "-tex-caligraphic-bold": {fonts: [MAIN,NORMAL,MONOSPACE,LATIN,ALPHABETS,MARKS,ARROWS,OPERATORS,SYMBOLS,SHAPES,MISC,VARIANTS,NONUNICODE,SIZE1], italic: true, bold: true},
@@ -157,9 +157,10 @@
            remap: {0x03F5: 52, 0x03D1: 53, 0x03F0: 54, 0x03D5: 55, 0x03F1: 56, 0x03D6: 57, 0x03F4: 17}}
       ],
 
-      RULECHAR: 0x0305,
+      RULECHAR: 0x2212,
 
       REMAP: {
+        0xA: 0x20,
         0x25C2: 0x25C0,
         0x3008: 0x27E8,
         0x3009: 0x27E9,
@@ -204,7 +205,7 @@
           HW: [[828,MAIN], [988,SIZE1], [1180,SIZE2], [1410,SIZE3], [1686,SIZE4], [2017,SIZE5], [2416,SIZE6], [2612,SIZE6,1.081]],
           stretch: {bot:[0x23A0,SYMBOLS], ext:[0x239F,SYMBOLS], top:[0x239E,SYMBOLS]}
         },
-        0x2D: {alias: 0x305, dir: H},
+        0x2D: {alias: 0x2212, dir: H},
         0x2F:
         {
           dir: V,
@@ -256,7 +257,7 @@
         0x7E: {alias: 0x303, dir: H},
         0xAF: {alias: 0x332, dir: H},
         0x2C6: {alias: 0x302, dir: H},
-        0x2C9: {alias: 0x305, dir: H},
+        0x2C9: {alias: 0x2212, dir: H},
         0x2DC: {alias: 0x303, dir: H},
         0x302:
         {
@@ -294,15 +295,15 @@
         },
         0x333: EXTRAH,
         0x33F: EXTRAH,
-        0x2015: {alias: 0x305, dir: H},
+        0x2015: {alias: 0x2212, dir: H},
         0x2016:
         {
           dir: V,
           HW: [[800,MAIN], [960,SIZE1], [1152,SIZE2], [1382,SIZE3], [1658,SIZE4], [1990,SIZE5], [2388,SIZE6]],
           stretch: {bot:[0xE12A,SIZE6], ext:[0xE12B,SIZE6], top:[0xE12C,SIZE6]}
         },
-        0x2017: {alias: 0x305, dir: H},
-        0x203E: {alias: 0x305, dir: H},
+        0x2017: {alias: 0x2212, dir: H},
+        0x203E: {alias: 0x2212, dir: H},
         0x2044:
         {
           dir: V,
@@ -473,9 +474,8 @@
         0x2211: EXTRAV,
         0x2212:
         {
-          dir: H,
-          HW: [[600,MAIN]],
-          stretch: {left:[0xE127,SIZE6], rep:[0xE128,SIZE6], right:[0xE129,SIZE6]}
+          HW: [],
+          stretch: {rep:[0x2212,MAIN,0,0,0,-.27,-.28]}
         },
         0x2215: {alias: 0x2044, dir: V},
         0x221A:
@@ -558,7 +558,7 @@
           HW: [[596,SYMBOLS]],
           stretch: {ext:[0x23AA,SYMBOLS]}
         },
-        0x23AF: {alias: 0x305, dir: H},
+        0x23AF: {alias: 0x2212, dir: H},
         0x23B0:
         {
           dir: V,
@@ -595,7 +595,7 @@
         },
         0x23E0: EXTRAH,
         0x23E1: EXTRAH,
-        0x2500: {alias: 0x305, dir: H},
+        0x2500: {alias: 0x2212, dir: H},
         0x27A1: EXTRAH,
         0x27E6: EXTRAV,
         0x27E7: EXTRAV,
@@ -670,6 +670,10 @@
 
     }
   });
+  MathJax.Hub.Register.LoadHook(SVG.fontDir+"/Main/Regular/Main.js",function () {
+    SVG.FONTDATA.FONTS[MAIN][0x2212][0] = SVG.FONTDATA.FONTS[MAIN][0x002B][0]; // - needs height and depth of +
+    SVG.FONTDATA.FONTS[MAIN][0x2212][1] = SVG.FONTDATA.FONTS[MAIN][0x002B][1]; // - needs height and depth of +
+  });
   MathJax.Hub.Register.LoadHook(SVG.fontDir+"/Size1/Regular/Main.js",function () {
     var i;
     for (i = 0x222B; i <= 0x222D; i++)
