@@ -1,11 +1,8 @@
-/* -*- Mode: Javascript; indent-tabs-mode:nil; js-indent-level: 2 -*- */
-/* vim: set ts=2 et sw=2 tw=80: */
-
 /*************************************************************
  *
  *  MathJax/localization/ast/ast.js
  *
- *  Copyright (c) 2009-2015 The MathJax Consortium
+ *  Copyright (c) 2009-2019 The MathJax Consortium
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -20,14 +17,13 @@
  *  limitations under the License.
  *
  */
-
 MathJax.Localization.addTranslation("ast",null,{
   menuTitle: "asturianu",
-  version: "2.6.0",
+  version: "2.7.7",
   isLoaded: true,
   domains: {
     "_": {
-        version: "2.6.0",
+        version: "2.7.7",
         isLoaded: true,
         strings: {
           CookieConfig: "MathJax alcontr\u00F3 una cookie de configuraci\u00F3n d'usuariu qu'incluye c\u00F3digu a executar. \u00BFQuier executar esi c\u00F3digu?\n\n(Tendr\u00EDa de calcar \u00ABEncaboxar\u00BB a menos que creara la cookie vust\u00E9 mesmu.)",
@@ -40,7 +36,8 @@ MathJax.Localization.addTranslation("ast",null,{
           Processing: "Procesando",
           TypesetMath: "Escribiendo matem\u00E1tiques: %1%%",
           Typesetting: "Componiendo",
-          MathJaxNotSupported: "El so navegador nun tien sofitu pa MathJax"
+          MathJaxNotSupported: "El so navegador nun tien sofitu pa MathJax",
+          ErrorTips: "Conseyos de depuraci\u00F3n: usa %%1, inspect %%2 na consola del restolador"
         }
     },
     "FontWarnings": {},
