@@ -1,11 +1,8 @@
-/* -*- Mode: Javascript; indent-tabs-mode:nil; js-indent-level: 2 -*- */
-/* vim: set ts=2 et sw=2 tw=80: */
-
 /*************************************************************
  *
  *  MathJax/localization/br/br.js
  *
- *  Copyright (c) 2009-2014 The MathJax Consortium
+ *  Copyright (c) 2009-2019 The MathJax Consortium
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -20,14 +17,13 @@
  *  limitations under the License.
  *
  */
-
 MathJax.Localization.addTranslation("br",null,{
   menuTitle: "brezhoneg",
-  version: "2.4.0",
+  version: "2.7.7",
   isLoaded: true,
   domains: {
     "_": {
-        version: "2.4.0",
+        version: "2.7.7",
         isLoaded: true,
         strings: {
           MathProcessingError: "Fazi o treta\u00F1 ar formulenn",
@@ -39,7 +35,8 @@ MathJax.Localization.addTranslation("br",null,{
           Processing: "O treta\u00F1",
           TypesetMath: "Aoza\u00F1 formulenno\u00F9 : %1%%",
           Typesetting: "Aoza\u00F1",
-          MathJaxNotSupported: "Ne c'hall ket ho merdeer ober gant MathJax"
+          MathJaxNotSupported: "Ne c'hall ket ho merdeer ober gant MathJax",
+          ErrorTips: "Alio\u00F9 dizreina\u00F1 : implijout %%1, ensellet %%2, e letrin ar merdeer"
         }
     },
     "FontWarnings": {},
