@@ -1,11 +1,8 @@
-/* -*- Mode: Javascript; indent-tabs-mode:nil; js-indent-level: 2 -*- */
-/* vim: set ts=2 et sw=2 tw=80: */
-
 /*************************************************************
  *
  *  MathJax/localization/mk/TeX.js
  *
- *  Copyright (c) 2009-2015 The MathJax Consortium
+ *  Copyright (c) 2009-2019 The MathJax Consortium
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -20,9 +17,8 @@
  *  limitations under the License.
  *
  */
-
 MathJax.Localization.addTranslation("mk","TeX",{
-        version: "2.6.0",
+        version: "2.7.7",
         isLoaded: true,
         strings: {
           ExtraOpenMissingClose: "\u0418\u043C\u0430\u0442\u0435 \u043D\u0435\u043F\u043E\u0442\u0440\u0435\u0431\u043D\u0430 \u043F\u043E\u0447\u0435\u0442\u043D\u0430 \u0437\u0430\u0433\u0440\u0430\u0434\u0430 \u0438\u043B\u0438 \u043D\u0435\u0434\u043E\u0441\u0442\u0430\u0441\u0443\u0432\u0430 \u0437\u0430\u0432\u0440\u0448\u043D\u0430",
@@ -51,8 +47,8 @@ MathJax.Localization.addTranslation("mk","TeX",{
           NotMathMLToken: "%1 \u043D\u0435 \u0435 \u0448\u0438\u0444\u0440\u0435\u043D \u0435\u043B\u0435\u043C\u0435\u043D\u0442",
           InvalidMathMLAttr: "\u041D\u0435\u0432\u0430\u0436\u0435\u0447\u043A\u0438 MathML-\u0430\u0442\u0440\u0438\u0431\u0443\u0442: %1",
           UnknownAttrForElement: "%1 \u043D\u0435 \u0435 \u043F\u0440\u0438\u0437\u043D\u0430\u0435\u043D \u0430\u0442\u0440\u0438\u0431\u0443\u0442 \u0437\u0430 %2",
-          MaxMacroSub1: "\u041D\u0430\u0434\u043C\u0438\u043D\u0430\u0442 \u0435 \u043C\u0430\u043A\u0441\u0438\u043C\u0430\u043B\u043D\u0438\u043E\u0442 \u0431\u0440\u043E\u0458 \u043D\u0430 \u043C\u0430\u043A\u0440\u043E\u0437\u0430\u043C\u0435\u043D\u0438 \u0432\u043E MathJax. \u0414\u0430 \u043D\u0435 \u0438\u043C\u0430 \u0440\u0435\u043A\u0443\u0440\u0437\u0438\u0432\u043D\u043E \u043F\u043E\u0432\u0438\u043A\u0443\u0432\u0430\u045A\u0435 \u043D\u0430 \u043C\u0430\u043A\u0440\u043E\u0437\u0430\u043C\u0435\u043D\u0430\u0442\u0430?",
-          MaxMacroSub2: "\u041D\u0430\u0434\u043C\u0438\u043D\u0430\u0442 \u0435 \u043C\u0430\u043A\u0441\u0438\u043C\u0430\u043B\u043D\u0438\u043E\u0442 \u0431\u0440\u043E\u0458 \u043D\u0430 \u043C\u0430\u043A\u0440\u043E\u0437\u0430\u043C\u0435\u043D\u0438 \u0432\u043E MathJax. \u0414\u0430 \u043D\u0435 \u0438\u043C\u0430 \u0440\u0430\u043A\u0443\u0440\u0437\u0438\u0432\u043D\u0430 LaTeX-\u043E\u043A\u043E\u043B\u0438\u043D\u0430?",
+          MaxMacroSub1: "\u041D\u0430\u0434\u043C\u0438\u043D\u0430\u0442 \u0435 \u043D\u0430\u0458\u0433\u043E\u043B\u0435\u043C\u0438\u043E\u0442 \u0434\u043E\u043F\u0443\u0448\u0442\u0435\u043D \u0431\u0440\u043E\u0458 \u043D\u0430 \u043C\u0430\u043A\u0440\u043E\u0437\u0430\u043C\u0435\u043D\u0438 \u0432\u043E MathJax. \u0414\u0430 \u043D\u0435 \u0438\u043C\u0430 \u0440\u0435\u043A\u0443\u0440\u0437\u0438\u0432\u043D\u043E \u043F\u043E\u0432\u0438\u043A\u0443\u0432\u0430\u045A\u0435 \u043D\u0430 \u043C\u0430\u043A\u0440\u043E\u0437\u0430\u043C\u0435\u043D\u0430\u0442\u0430?",
+          MaxMacroSub2: "\u041D\u0430\u0434\u043C\u0438\u043D\u0430\u0442 \u0435 \u043D\u0430\u0458\u0433\u043E\u043B\u0435\u043C\u0438\u043E\u0442 \u0434\u043E\u043F\u0443\u0448\u0442\u0435\u043D \u0431\u0440\u043E\u0458 \u043D\u0430 \u043C\u0430\u043A\u0440\u043E\u0437\u0430\u043C\u0435\u043D\u0438 \u0432\u043E MathJax. \u0414\u0430 \u043D\u0435 \u0438\u043C\u0430 \u0440\u0430\u043A\u0443\u0440\u0437\u0438\u0432\u043D\u0430 LaTeX-\u043E\u043A\u043E\u043B\u0438\u043D\u0430?",
           MissingArgFor: "\u041D\u0435\u0434\u043E\u0441\u0442\u0430\u0441\u0443\u0432\u0430 \u0430\u0440\u0433\u0443\u043C\u0435\u043D\u0442 \u0437\u0430 %1",
           ExtraAlignTab: "\u041D\u0435\u043F\u043E\u0442\u0440\u0435\u0431\u0435\u043D \u0437\u043D\u0430\u043A \u0437\u0430 \u043F\u043E\u0440\u0430\u043C\u043D\u0443\u0432\u0430\u045A\u0435 \u0432\u043E \u0442\u0435\u043A\u0441\u0442\u043E\u0442 \u043D\u0430 \u201E\\cases\u201C",
           BracketMustBeDimension: "\u0417\u0430\u0433\u0440\u0430\u0434\u0435\u043D\u0438\u043E\u0442 \u0430\u0440\u0433\u0443\u043C\u0435\u043D\u0442 \u0437\u0430 %1 \u043C\u043E\u0440\u0430 \u0434\u0430 \u0431\u0438\u0434\u0435 \u0434\u0438\u043C\u0435\u043D\u0437\u0438\u0458\u0430",
