@@ -2,7 +2,7 @@
  *
  *  MathJax/localization/pl/MathMenu.js
  *
- *  Copyright (c) 2009-2016 The MathJax Consortium
+ *  Copyright (c) 2009-2019 The MathJax Consortium
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -18,7 +18,7 @@
  *
  */
 MathJax.Localization.addTranslation("pl","MathMenu",{
-        version: "2.7.0",
+        version: "2.7.7",
         isLoaded: true,
         strings: {
           Show: "Poka\u017C wzory jako",
@@ -100,7 +100,11 @@ MathJax.Localization.addTranslation("pl","MathMenu",{
           GyrePagellaWeb: "Gyre Pagella (www)",
           GyreTermesWeb: "Gyre Termes (www)",
           LatinModernWeb: "Latin Modern (www)",
-          NeoEulerWeb: "Neo Euler (www)"
+          NeoEulerWeb: "Neo Euler (www)",
+          CloseAboutDialog: "Zamknij okno o MathJax",
+          FastPreview: "Szybki podgl\u0105d strony",
+          AssistiveMML: "Asystuj\u0105cy MathML",
+          InTabOrder: "Zawarty w kolejno\u015Bci stron"
         }
 });
 
