@@ -1,11 +1,8 @@
-/* -*- Mode: Javascript; indent-tabs-mode:nil; js-indent-level: 2 -*- */
-/* vim: set ts=2 et sw=2 tw=80: */
-
 /*************************************************************
  *
  *  MathJax/localization/ru/MathMenu.js
  *
- *  Copyright (c) 2009-2015 The MathJax Consortium
+ *  Copyright (c) 2009-2019 The MathJax Consortium
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -20,9 +17,8 @@
  *  limitations under the License.
  *
  */
-
 MathJax.Localization.addTranslation("ru","MathMenu",{
-        version: "2.5.0",
+        version: "2.7.7",
         isLoaded: true,
         strings: {
           Show: "\u041F\u043E\u043A\u0430\u0437\u0430\u0442\u044C \u043A\u043E\u0434 \u0444\u043E\u0440\u043C\u0443\u043B\u044B \u0432\u00A0\u0432\u0438\u0434\u0435:",
@@ -104,7 +100,11 @@ MathJax.Localization.addTranslation("ru","MathMenu",{
           IE9warning: "\u041A\u043E\u043D\u0442\u0435\u043A\u0441\u0442\u043D\u043E\u0435 \u043C\u0435\u043D\u044E MathJax \u0431\u0443\u0434\u0435\u0442 \u043E\u0442\u043A\u043B\u044E\u0447\u0435\u043D\u043E, \u043D\u043E\u00A0\u043F\u043E \u0449\u0435\u043B\u0447\u043A\u0443 \u043C\u044B\u0448\u044C\u044E \u0441\u00A0\u043D\u0430\u0436\u0430\u0442\u043E\u0439 Alt \u043E\u043D\u043E \u043F\u043E-\u043F\u0440\u0435\u0436\u043D\u0435\u043C\u0443 \u0431\u0443\u0434\u0435\u0442 \u0434\u043E\u0441\u0442\u0443\u043F\u043D\u043E.",
           NoOriginalForm: "\u041D\u0435\u0442 \u0438\u0441\u0445\u043E\u0434\u043D\u043E\u0433\u043E \u043A\u043E\u0434\u0430",
           Close: "\u0417\u0430\u043A\u0440\u044B\u0442\u044C",
-          EqSource: "\u0418\u0441\u0445\u043E\u0434\u043D\u044B\u0439 \u043A\u043E\u0434 \u0444\u043E\u0440\u043C\u0443\u043B\u044B"
+          EqSource: "\u0418\u0441\u0445\u043E\u0434\u043D\u044B\u0439 \u043A\u043E\u0434 \u0444\u043E\u0440\u043C\u0443\u043B\u044B",
+          CloseAboutDialog: "\u0417\u0430\u043A\u0440\u044B\u0442\u044C \u0434\u0438\u0430\u043B\u043E\u0433 \"\u041E \u043F\u0440\u043E\u0433\u0440\u0430\u043C\u043C\u0435\"",
+          FastPreview: "\u0411\u044B\u0441\u0442\u0440\u044B\u0439 \u041F\u0440\u043E\u0441\u043C\u043E\u0442\u0440",
+          AssistiveMML: "\u0412\u0441\u043F\u043E\u043C\u043E\u0433\u0430\u0442\u0435\u043B\u044C\u043D\u044B\u0439 MathML",
+          InTabOrder: "\u0412\u043A\u043B\u044E\u0447\u0430\u0442\u044C \u0432 \u043F\u043E\u0440\u044F\u0434\u043A\u0435 \u0442\u0430\u0431\u0443\u043B\u044F\u0446\u0438\u0438"
         }
 });
 
