@@ -1,11 +1,8 @@
-/* -*- Mode: Javascript; indent-tabs-mode:nil; js-indent-level: 2 -*- */
-/* vim: set ts=2 et sw=2 tw=80: */
-
 /*************************************************************
  *
  *  MathJax/localization/vi/HelpDialog.js
  *
- *  Copyright (c) 2009-2015 The MathJax Consortium
+ *  Copyright (c) 2009-2019 The MathJax Consortium
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -20,9 +17,8 @@
  *  limitations under the License.
  *
  */
-
 MathJax.Localization.addTranslation("vi","HelpDialog",{
-        version: "2.6.0",
+        version: "2.7.7",
         isLoaded: true,
         strings: {
           Help: "Tr\u1EE3 gi\u00FAp MathJax",
@@ -34,7 +30,8 @@ MathJax.Localization.addTranslation("vi","HelpDialog",{
           Language: "*Ng\u00F4n ng\u1EEF* cho ph\u00E9p l\u1EF1a ch\u1ECDn ng\u00F4n ng\u1EEF cho c\u00E1c tr\u00ECnh \u0111\u01A1n v\u00E0 th\u00F4ng \u0111i\u1EC7p trong MathJax.",
           Zoom: "*Ph\u00F3ng to*: N\u1EBFu b\u1EA1n c\u1EA3m th\u1EA5y kh\u00F3 \u0111\u1ECDc m\u1ED9t ph\u01B0\u01A1ng tr\u00ECnh, MathJax c\u00F3 th\u1EC3 ph\u00F3ng to n\u00F3 \u0111\u1EC3 gi\u00FAp b\u1EA1n th\u1EA5y r\u00F5 h\u01A1n.",
           Accessibilty: "*Tr\u1EE3 n\u0103ng*: MathJax t\u1EF1 \u0111\u1ED9ng t\u00E1c \u0111\u1ED9ng v\u1EDBi c\u00E1c tr\u00ECnh \u0111\u1ECDc m\u00E0n h\u00ECnh \u0111\u1EC3 gi\u00FAp ng\u01B0\u1EDDi m\u00F9 l\u00F2a truy c\u1EADp to\u00E1n h\u1ECDc.",
-          Fonts: "*Ph\u00F4ng ch\u1EEF*: MathJax s\u1EED d\u1EE5ng m\u1ED9t s\u1ED1 ph\u00F4ng ch\u1EEF to\u00E1n h\u1ECDc n\u1EBFu \u0111\u01B0\u1EE3c c\u00E0i \u0111\u1EB7t tr\u00EAn m\u00E1y c\u1EE7a b\u1EA1n; n\u1EBFu kh\u00F4ng, n\u00F3 t\u1EA3i c\u00E1c ph\u00F4ng ch\u1EEF Web. B\u1EA1n c\u00F3 th\u1EC3 (nh\u01B0ng kh\u00F4ng c\u1EA7n ph\u1EA3i) c\u00E0i \u0111\u1EB7t c\u00E1c ph\u00F4ng ch\u1EEF v\u00E0o m\u00E1y \u0111\u1EC3 t\u0103ng t\u1ED1c \u0111\u1ED9 s\u1EAFp ch\u1EEF. Ch\u00FAng t\u00F4i khuy\u1EBFn kh\u00EDch c\u00E0i \u0111\u1EB7t c\u00E1c [ph\u00F4ng ch\u1EEF STIX](%1)."
+          Fonts: "*Ph\u00F4ng ch\u1EEF*: MathJax s\u1EED d\u1EE5ng m\u1ED9t s\u1ED1 ph\u00F4ng ch\u1EEF to\u00E1n h\u1ECDc n\u1EBFu \u0111\u01B0\u1EE3c c\u00E0i \u0111\u1EB7t tr\u00EAn m\u00E1y c\u1EE7a b\u1EA1n; n\u1EBFu kh\u00F4ng, n\u00F3 t\u1EA3i c\u00E1c ph\u00F4ng ch\u1EEF Web. B\u1EA1n c\u00F3 th\u1EC3 (nh\u01B0ng kh\u00F4ng c\u1EA7n ph\u1EA3i) c\u00E0i \u0111\u1EB7t c\u00E1c ph\u00F4ng ch\u1EEF v\u00E0o m\u00E1y \u0111\u1EC3 t\u0103ng t\u1ED1c \u0111\u1ED9 s\u1EAFp ch\u1EEF. Ch\u00FAng t\u00F4i khuy\u1EBFn kh\u00EDch c\u00E0i \u0111\u1EB7t c\u00E1c [ph\u00F4ng ch\u1EEF STIX](%1).",
+          CloseDialog: "\u0110\u00F3ng h\u1ED9p tho\u1EA1i tr\u1EE3 gi\u00FAp"
         }
 });
 
