@@ -1,11 +1,8 @@
-/* -*- Mode: Javascript; indent-tabs-mode:nil; js-indent-level: 2 -*- */
-/* vim: set ts=2 et sw=2 tw=80: */
-
 /*************************************************************
  *
  *  MathJax/localization/zh-hans/HelpDialog.js
  *
- *  Copyright (c) 2009-2015 The MathJax Consortium
+ *  Copyright (c) 2009-2019 The MathJax Consortium
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -20,9 +17,8 @@
  *  limitations under the License.
  *
  */
-
 MathJax.Localization.addTranslation("zh-hans","HelpDialog",{
-        version: "2.6.0",
+        version: "2.7.7",
         isLoaded: true,
         strings: {
           Help: "MathJax\u5E2E\u52A9",
@@ -34,7 +30,8 @@ MathJax.Localization.addTranslation("zh-hans","HelpDialog",{
           Language: "*\u8BED\u8A00*\u7ED9\u60A8\u9009\u62E9MathJax\u7528\u4F5C\u83DC\u5355\u548C\u8B66\u544A\u4FE1\u606F\u7684\u8BED\u8A00\u3002",
           Zoom: "*\u6570\u5F0F\u7F29\u653E*\uFF1A\u5982\u679C\u60A8\u6D4F\u89C8\u7B49\u5F0F\u65F6\u9047\u5230\u56F0\u96BE\uFF0CMathJax\u53EF\u4EE5\u5C06\u5176\u653E\u5927\u6765\u4F7F\u60A8\u83B7\u5F97\u66F4\u597D\u7684\u4F53\u9A8C\u3002",
           Accessibilty: "*\u8F85\u52A9\u529F\u80FD*\uFF1AMathJax\u4F1A\u81EA\u52A8\u4E0E\u8BBF\u95EE\u8005\u4EA4\u4E92\u4F7F\u89C6\u89C9\u969C\u788D\u8005\u7406\u89E3\u6570\u5F0F\u66F4\u52A0\u5BB9\u6613\u3002",
-          Fonts: "*\u5B57\u4F53*\uFF1AMathJax\u5C06\u4F1A\u4F7F\u7528\u60A8\u7535\u8111\u4E0A\u5B89\u88C5\u7684\u67D0\u4E9B\u6570\u5F0F\u5B57\u4F53\u6765\u663E\u793A\u6570\u5F0F\uFF1B\u5982\u679C\u6CA1\u6709\u5B89\u88C5\u7684\u8BDD\uFF0C\u5B83\u5C06\u4F7F\u7528\u7F51\u7EDC\u4E0A\u7684\u5B57\u4F53\u3002\u867D\u7136\u5E76\u975E\u5FC5\u8981\uFF0C\u4F46\u662F\u5C06\u8FD9\u4E9B\u5B57\u4F53\u5B89\u88C5\u5230\u672C\u5730\u80FD\u52A0\u901F\u6570\u5F0F\u7684\u663E\u793A\u3002\u6211\u4EEC\u5EFA\u8BAE\u60A8\u5B89\u88C5[STIX fonts](%1)\u3002"
+          Fonts: "*\u5B57\u4F53*\uFF1AMathJax\u5C06\u4F1A\u4F7F\u7528\u60A8\u7535\u8111\u4E0A\u5B89\u88C5\u7684\u67D0\u4E9B\u6570\u5F0F\u5B57\u4F53\u6765\u663E\u793A\u6570\u5F0F\uFF1B\u5982\u679C\u6CA1\u6709\u5B89\u88C5\u7684\u8BDD\uFF0C\u5B83\u5C06\u4F7F\u7528\u7F51\u7EDC\u4E0A\u7684\u5B57\u4F53\u3002\u867D\u7136\u5E76\u975E\u5FC5\u8981\uFF0C\u4F46\u662F\u5C06\u8FD9\u4E9B\u5B57\u4F53\u5B89\u88C5\u5230\u672C\u5730\u80FD\u52A0\u901F\u6570\u5F0F\u7684\u663E\u793A\u3002\u6211\u4EEC\u5EFA\u8BAE\u60A8\u5B89\u88C5[STIX fonts](%1)\u3002",
+          CloseDialog: "\u5173\u95ED\u5E2E\u52A9\u5BF9\u8BDD"
         }
 });
 
