@@ -1,11 +1,8 @@
-/* -*- Mode: Javascript; indent-tabs-mode:nil; js-indent-level: 2 -*- */
-/* vim: set ts=2 et sw=2 tw=80: */
-
 /*************************************************************
  *
  *  MathJax/localization/zh-hans/MathMenu.js
  *
- *  Copyright (c) 2009-2015 The MathJax Consortium
+ *  Copyright (c) 2009-2019 The MathJax Consortium
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -20,9 +17,8 @@
  *  limitations under the License.
  *
  */
-
 MathJax.Localization.addTranslation("zh-hans","MathMenu",{
-        version: "2.6.0",
+        version: "2.7.7",
         isLoaded: true,
         strings: {
           Show: "\u6570\u5F0F\u663E\u793A\u5F62\u5F0F",
@@ -37,7 +33,7 @@ MathJax.Localization.addTranslation("zh-hans","MathMenu",{
           StarMath: "StarMath",
           Maple: "\u67AB\u53F6",
           ContentMathML: "MathML\u5185\u5BB9",
-          OpenMath: "\u5F00\u6E90\u6570\u5B66",
+          OpenMath: "OpenMath",
           texHints: "\u5728MathML\u4E2D\u663E\u793ATeX\u63D0\u793A",
           Settings: "\u6570\u5B66\u8BBE\u7F6E",
           ZoomTrigger: "\u7F29\u653E\u89E6\u53D1",
@@ -104,7 +100,11 @@ MathJax.Localization.addTranslation("zh-hans","MathMenu",{
           GyrePagellaWeb: "Gyre Pagella (web)",
           GyreTermesWeb: "Gyre Termes (web)",
           NeoEulerWeb: "Neo Euler (web)",
-          MSIESVGWarning: "SVG\u5728 IE9 \u4E4B\u524D\u7684 Internet Explorer \u6216\u4F7F\u7528 IE8 \u53CA\u4EE5\u4E0B\u67B6\u6784\u7684\u6D4F\u89C8\u5668\u4E2D\u4E0D\u6267\u884C\u3002\u8F6C\u6362SVG\u8F93\u51FA\u5C06\u5BFC\u81F4\u6570\u5B66\u516C\u5F0F\u4E0D\u80FD\u6B63\u5E38\u663E\u793A\u3002"
+          MSIESVGWarning: "SVG\u5728 IE9 \u4E4B\u524D\u7684 Internet Explorer \u6216\u4F7F\u7528 IE8 \u53CA\u4EE5\u4E0B\u67B6\u6784\u7684\u6D4F\u89C8\u5668\u4E2D\u4E0D\u6267\u884C\u3002\u8F6C\u6362SVG\u8F93\u51FA\u5C06\u5BFC\u81F4\u6570\u5B66\u516C\u5F0F\u4E0D\u80FD\u6B63\u5E38\u663E\u793A\u3002",
+          CloseAboutDialog: "\u5173\u95ED\u6709\u5173MathJax\u5BF9\u8BDD",
+          FastPreview: "\u5FEB\u901F\u9884\u89C8",
+          AssistiveMML: "\u8F85\u52A9MathML",
+          InTabOrder: "\u5305\u542B\u5728\u6807\u7B7E\u987A\u5E8F\u4E2D"
         }
 });
 
